﻿using System;
using System.Collections.Generic;
using Microsoft.EntityFrameworkCore;

namespace FoodLogProject;

public partial class GaruaevContext : DbContext
{

    public GaruaevContext()
    {
    }

    public GaruaevContext(DbContextOptions<GaruaevContext> options)
        : base(options)
    {
    }

    public virtual DbSet<Customer> Customers { get; set; }

    public virtual DbSet<CustomersIngredient> CustomersIngredients { get; set; }

    public virtual DbSet<Ingredient> Ingredients { get; set; }

    public virtual DbSet<Order> Orders { get; set; }

    public virtual DbSet<Recipe> Recipes { get; set; }

    public virtual DbSet<RecipesIngredient> RecipesIngredients { get; set; }

    public virtual DbSet<RecipesOrder> RecipesOrders { get; set; }

    public virtual DbSet<Supplier> Suppliers { get; set; }

    protected override void OnConfiguring(DbContextOptionsBuilder optionsBuilder)
#warning To protect potentially sensitive information in your connection string, you should move it out of source code. You can avoid scaffolding the connection string by using the Name= syntax to read it from configuration - see https://go.microsoft.com/fwlink/?linkid=2131148. For more guidance on storing connection strings, see http://go.microsoft.com/fwlink/?LinkId=723263.
        => optionsBuilder.UseNpgsql("Host=edu.pg.ngknn.ru;Port=5442;Database=Garuaev;Username=33P;Password=12345");

    protected override void OnModelCreating(ModelBuilder modelBuilder)
    {
        modelBuilder.Entity<Customer>(entity =>
        {
            entity.HasKey(e => e.CustomerId).HasName("customer_id_pk");

            entity.ToTable("customers");

            entity.HasIndex(e => e.CustomerPhone, "customer_phone_key").IsUnique();

            entity.Property(e => e.CustomerId).HasColumnName("customer_id");
            entity.Property(e => e.CustomerAdress)
                .HasMaxLength(20)
                .HasColumnName("customer_adress");
            entity.Property(e => e.CustomerBirthdate).HasColumnName("customer_birthdate");
            entity.Property(e => e.CustomerGender).HasColumnName("customer_gender");
            entity.Property(e => e.CustomerHeight).HasColumnName("customer_height");
            entity.Property(e => e.CustomerNickname)
                .HasMaxLength(20)
                .HasColumnName("customer_nickname");
            entity.Property(e => e.CustomerPassword)
                .HasMaxLength(20)
                .HasColumnName("customer_password");
            entity.Property(e => e.CustomerPhone)
                .HasMaxLength(20)
                .HasColumnName("customer_phone");
            entity.Property(e => e.CustomerWeight).HasColumnName("customer_weight");
        });

        modelBuilder.Entity<CustomersIngredient>(entity =>
        {
            entity
                .HasNoKey()
                .ToTable("customers_ingredients");

            entity.Property(e => e.CustomerId).HasColumnName("customer_id");
            entity.Property(e => e.IngredientId).HasColumnName("ingredient_id");

            entity.HasOne(d => d.Customer).WithMany()
                .HasForeignKey(d => d.CustomerId)
                .OnDelete(DeleteBehavior.ClientSetNull)
                .HasConstraintName("customers_ingredients_customer_id_fkey");

            entity.HasOne(d => d.Ingredient).WithMany()
                .HasForeignKey(d => d.IngredientId)
                .OnDelete(DeleteBehavior.ClientSetNull)
                .HasConstraintName("customers_ingredients_ingredient_id_fkey");
        });

        modelBuilder.Entity<Ingredient>(entity =>
        {
            entity.HasKey(e => e.IngredientId).HasName("ingredient_id_pk");

            entity.ToTable("ingredients");

            entity.Property(e => e.IngredientId).HasColumnName("ingredient_id");
            entity.Property(e => e.IngredientName)
                .HasMaxLength(20)
                .HasColumnName("ingredient_name");
        });

        modelBuilder.Entity<Order>(entity =>
        {
            entity.HasKey(e => e.OrderId).HasName("order_id_pk");

            entity.ToTable("orders");

            entity.Property(e => e.OrderId).HasColumnName("order_id");
            entity.Property(e => e.CustomerId).HasColumnName("customer_id");
            entity.Property(e => e.OrderDate).HasColumnName("order_date");
            entity.Property(e => e.SupplierId).HasColumnName("supplier_id");

            entity.HasOne(d => d.Customer).WithMany(p => p.Orders)
                .HasForeignKey(d => d.CustomerId)
                .OnDelete(DeleteBehavior.ClientSetNull)
                .HasConstraintName("orders_customer_id_fkey");

            entity.HasOne(d => d.Supplier).WithMany(p => p.Orders)
                .HasForeignKey(d => d.SupplierId)
                .OnDelete(DeleteBehavior.ClientSetNull)
                .HasConstraintName("orders_supplier_id_fkey");
        });

        modelBuilder.Entity<Recipe>(entity =>
        {
            entity.HasKey(e => e.RecipeId).HasName("recipe_id_pk");

            entity.ToTable("recipes");

            entity.Property(e => e.RecipeId).HasColumnName("recipe_id");
            entity.Property(e => e.RecipeDescription)
                .HasMaxLength(2000)
                .HasColumnName("recipe_description");
            entity.Property(e => e.RecipeName)
                .HasMaxLength(20)
                .HasColumnName("recipe_name");
        });

        modelBuilder.Entity<RecipesIngredient>(entity =>
        {
            entity
                .HasNoKey()
                .ToTable("recipes_ingredients");

            entity.Property(e => e.IngredientId).HasColumnName("ingredient_id");
            entity.Property(e => e.RecipeId).HasColumnName("recipe_id");
            entity.Property(e => e.Weight)
                .HasMaxLength(50)
                .HasColumnName("weight");

            entity.HasOne(d => d.Ingredient).WithMany()
                .HasForeignKey(d => d.IngredientId)
                .OnDelete(DeleteBehavior.ClientSetNull)
                .HasConstraintName("recipes_ingredients_ingredient_id_fkey");

            entity.HasOne(d => d.Recipe).WithMany()
                .HasForeignKey(d => d.RecipeId)
                .OnDelete(DeleteBehavior.ClientSetNull)
                .HasConstraintName("recipes_ingredients_recipe_id_fkey");
        });

        modelBuilder.Entity<RecipesOrder>(entity =>
        {
            entity
                .HasNoKey()
                .ToTable("recipes_orders");

            entity.Property(e => e.OrderId).HasColumnName("order_id");
            entity.Property(e => e.RecipeId).HasColumnName("recipe_id");

            entity.HasOne(d => d.Order).WithMany()
                .HasForeignKey(d => d.OrderId)
                .OnDelete(DeleteBehavior.ClientSetNull)
                .HasConstraintName("recipes_orders_order_id_fkey");

            entity.HasOne(d => d.Recipe).WithMany()
                .HasForeignKey(d => d.RecipeId)
                .OnDelete(DeleteBehavior.ClientSetNull)
                .HasConstraintName("recipes_orders_recipe_id_fkey");
        });

        modelBuilder.Entity<Supplier>(entity =>
        {
            entity.HasKey(e => e.SupplierId).HasName("supplier_id_pk");

            entity.ToTable("suppliers");

            entity.HasIndex(e => e.SupplierPhone, "supplier_phone_key").IsUnique();

            entity.Property(e => e.SupplierId).HasColumnName("supplier_id");
            entity.Property(e => e.SupplierName)
                .HasMaxLength(20)
                .HasColumnName("supplier_name");
            entity.Property(e => e.SupplierPhone)
                .HasMaxLength(20)
                .HasColumnName("supplier_phone");
        });

        OnModelCreatingPartial(modelBuilder);
    }

    partial void OnModelCreatingPartial(ModelBuilder modelBuilder);
}
